@@ -316,7 +316,7 @@ pub trait Context:
 
 #[async_trait]
 pub trait ContextProvider<T: Context> {
-    async fn new_context(self) -> Result<T, Error>;
+    async fn new_context(&self) -> Result<T, Error>;
 }
 
 fn new_invalid_state_error(msg: &str) -> Error {
